@@ -5,13 +5,10 @@ def preflight(*args):
     return "", 204, {
         "Access-Control-Allow-Origin": "*",
         "Access-Control-Allow-Methods": "GET",
-        "Access-Control-Allow-Headers": "Content-Type",
+        "Access-Control-Allow-Headers": "*",
         "Access-Control-Max-Age": "3600"
     }
 
-def cors(response, code):
-    return response, code, { "Access-Control-Allow-Origin": "*"}
-
 class Endpoint:
     http_verbs = ["get", "head", "post", "put", "delete", "connect", "options",
                   "trace", "patch"]
@@ -33,4 +30,4 @@ class Endpoint:
         if method not in methods:
             return not_allowed
 
-        return cors(*getattr(cls, method))
+        return getattr(cls, method)
